#!/usr/bin/env python
#
# This file is part of python-rhev. python-rhev is free software that is
# made available under the MIT license. Consult the file "LICENSE" that
# is distributed together with this file for the exact licensing terms.
#
# python-rhev is copyright (c) 2010-2011 by the python-rhev authors. See
# the file "AUTHORS" for a complete overview.

# This example illustrates the use of the history database. It uses psycopg2
# to connect to the history db, and queries the CPU and memory utilization for
# a VM that is specified on the command line. The results are plotted
# graphically using matplotlib.

import sys

import rhev
from rhev import schema
import matplotlib.pyplot as plt
import common

common.create_parser(usage='%prog [options] <vmname>')
opts, args = common.parse_args()

if len(args) != 1:
    common.print_help()
    sys.exit(1)
vmname = args[0]

api = common.connect()

vm = api.get(schema.VM, name=vmname)
if not vm:
    sys.stderr.write('Error: vm not found: %s\n' % vmname)
    sys.exit(1)

db = common.connect_dwh()

cursor = db.cursor()
cursor.execute("""
        SELECT history_datetime, cpu_usage_percent,
               memory_usage_percent
        FROM vm_samples_history
        WHERE vm_id = %s AND history_datetime > NOW() - INTERVAL '30 minutes'
        ORDER BY history_datetime ASC
        """, (vm.id,))

result = cursor.fetchall()
# replace(tzinfo=None) -> address bug in matplotlib that ignores timezones
dates = [ r[0].replace(tzinfo=None) for r in result ]
cpu = [ r[1] for r in result ]
memory = [ r[2] for r in result ]

plt.plot(dates, cpu, label='CPU')
plt.plot(dates, memory, label='Memory')
plt.title(' %s utilization (last 30 minutes)' % vm.name)
plt.xlabel('Time')
plt.ylabel('Utilization (%)')
plt.ylim(0, 100)
plt.legend()
plt.show()
